@@ -1,6 +1,9 @@
 """Select2 view implementation."""
 
-import collections
+try:
+    from collections.abc import Sequence
+except ImportError:  # py < 3.10
+    from collections import Sequence
 # import json
 
 from dal.views import BaseQuerySetView, ViewMixin
@@ -8,7 +11,7 @@ from dal.views import BaseQuerySetView, ViewMixin
 from django import http
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import F
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.generic.list import View
 
 import six
@@ -16,6 +19,7 @@ import six
 
 class Select2ViewMixin(object):
     """View mixin to render a JSON response for Select2."""
+    case_sensitive_create = False
 
     def get_results(self, context):
         """Return data for the 'results' key of the response."""
@@ -36,12 +40,17 @@ class Select2ViewMixin(object):
             if page_obj is None or page_obj.number == 1:
                 display_create_option = True
 
-            # Don't offer to create a new option if a
-            # case-insensitive) identical one already exists
-            existing_options = (self.get_result_label(result).lower()
-                                for result in context['object_list'])
-            if q.lower() in existing_options:
-                display_create_option = False
+            if not self.case_sensitive_create:
+                # Don't offer to create a new option if a
+                # case-insensitive) identical one already exists
+                existing_options = (self.get_result_label(result).lower()
+                                    for result in context['object_list'])
+                if q.lower() in existing_options:
+                    display_create_option = False
+            else:
+                existing_options = (self.get_result_label(result) for result in context["object_list"])
+                if q in existing_options:
+                    display_create_option = False
 
         if display_create_option and self.has_add_permission(self.request):
             create_option = [{
@@ -108,9 +117,9 @@ class Select2GroupQuerySetView(Select2QuerySetView):
             'id': None,
             'text': group,
             'children': [{
-                'id': result.id,
-                'text': getattr(result, self.related_field_name),
-                'title': result.descricao
+                'id': self.get_result_value(result),
+                'text': self.get_result_label(result),
+                'selected_text': self.get_selected_result_label(result),
             } for result in results]
         } for group, results in groups.items()]
 
@@ -191,7 +200,7 @@ class Select2GroupListView(Select2ListView):
         group = None
         item = entry
 
-        if isinstance(entry, collections.Sequence) and \
+        if isinstance(entry, Sequence) and \
            not isinstance(entry, six.string_types):
 
             entry_length = len(entry)
@@ -209,7 +218,7 @@ class Select2GroupListView(Select2ListView):
                 elif(entry_length > 0):
                     item = entry[0]
 
-        if not isinstance(item, collections.Sequence) or \
+        if not isinstance(item, Sequence) or \
            isinstance(item, six.string_types):
             item = (item,)
 
